/*####################################################################
 FILE: pca9635.cpp
 VERSION: 1.0
 PURPOSE: I2C Circular LED Bar library for Arduino

 HISTORY:
 Mirko Prosseda - Original version (23/10/2013)
#######################################################################*/


#include "pca9635.h"
#include "Wire.h"


uint8_t pca9635::getRegister(uint8_t reg)
{
    Wire.beginTransmission(address);    // address the pca9635
    Wire.write(reg);                    // point to the selected register
    Wire.endTransmission();             // execute comand

    Wire.requestFrom(address, 1);       // requires 1 byte from the pca9635
    uint8_t c = Wire.read();            // receive the byte
    return c;                           // return register value
}


void pca9635::setRegister(uint8_t reg, uint8_t value)
{
    Wire.beginTransmission(address);    // address the pca9635
    Wire.write(reg);                    // point to the selected register
    Wire.write(value);                  // write value to the selected register
    Wire.endTransmission();             // execute comand
    delayMicroseconds(5);               // bus free time between a STOP and START condition
}


void pca9635::setBrightness(uint8_t ch, uint8_t value)
{
    if(ch > 1 && ch < 18)        // ch value must be from 2 to 17
        setRegister(ch, value);
}


void pca9635::initialize()
{
  setRegister(MODE1, getRegister(MODE1) & 0xEF); // Exit PCA9635 from Sleep
  setRegister(MODE2, getRegister(MODE2) | 0x10); // Invert output logic levels

  setRegister(LEDOUT0, 0xAA); // All LED driver individual brightness can
  setRegister(LEDOUT1, 0xAA); // be controlled through its PWM register
  setRegister(LEDOUT2, 0xAA);
  setRegister(LEDOUT3, 0xAA);
}
